@@ -286,7 +286,7 @@ def call_function(function_name, data):
             call = function.call(data)
             call_complete = True
         except CogniteAPIError:
-            logging.warning(f"Cognite API error, try again ({call.id=})")
+            logging.warning(f"Cognite API error, try again")
     logging.debug(f"Called function ({call.id=})")
     response = call.get_response()
     t_proc = time.process_time() - t_start
