@@ -1,11 +1,11 @@
 #setup.py
-import os
 from pathlib import Path
 
 from akerbp.mlops import __version__ as version
 from akerbp.mlops.core import logger 
 from akerbp.mlops.deployment.helpers import to_folder, replace_string_file
 from  akerbp.mlops.core.config import generate_default_project_settings
+from  akerbp.mlops.core.config import validate_user_settings
 
 logging=logger.get_logger(name='mlops_deployment')
 
@@ -27,9 +27,13 @@ def setup_pipeline(folder_path=Path('.'), overwrite=False):
 
 
 if __name__ == '__main__':
-    logging.info("Create pipeline file")
-    setup_pipeline() 
-    logging.info("Create settings file template")
-    generate_default_project_settings()
+    logging.info("Create or overwrite pipeline file")
+    setup_pipeline(overwrite=True) 
+    if Path('mlops_settings.yaml').exists():
+        logging.info("Validate settings file")
+        validate_user_settings()
+    else:
+        logging.info("Create settings file template")
+        generate_default_project_settings()
     logging.info("Done!")
 
